@@ -46,7 +46,7 @@ from .ubx_cfgval_frame import UBX_CFGVAL_Frame
 from .ubx_solrate_frame import UBX_RATE_Frame
 
 
-class UBXConfigDialog:
+class UBXConfigDialog(Toplevel):
     """,
     UBXConfigDialog class.
     """
@@ -62,20 +62,11 @@ class UBXConfigDialog:
 
         self.__app = app  # Reference to main application class
         self.__master = self.__app.get_master()  # Reference to root class (Tk)
-        self._dialog = Toplevel()
-        self._dialog.transient(self.__app)
-        self._dialog.resizable(False, False)
-        self._dialog.title = DLGUBXCONFIG
-        self._dialog.protocol("WM_DELETE_WINDOW", self.on_exit)
-        # roughly center dialog in master window
-        # NB: this works on Windows and MacOS but not on some Linux
-        dw = 780
-        dh = 470
-        mx = self.__master.winfo_x()
-        my = self.__master.winfo_y()
-        mw = self.__master.winfo_width()
-        mh = self.__master.winfo_height()
-        self._dialog.geometry(f"+{int(mx + (mw/2 - dw/2))}+{int(my + (mh/2 - dh/2))}")
+        Toplevel.__init__(self, app)
+        self.transient(self.__app)
+        self.resizable(False, False)
+        self.title(DLGUBXCONFIG)  # pylint: disable=E1102
+        self.protocol("WM_DELETE_WINDOW", self.on_exit)
         self._img_exit = ImageTk.PhotoImage(Image.open(ICON_EXIT))
         self._cfg_msg_command = None
         self._pending_confs = {
@@ -93,21 +84,14 @@ class UBXConfigDialog:
         self._body()
         self._do_layout()
         self._reset()
+        self._centre()
 
     def _body(self):
         """
         Set up frame and widgets.
         """
 
-        self._frm_container = Frame(self._dialog, borderwidth=2, relief="groove")
-        self._lbl_title = Label(
-            self._frm_container,
-            text=LBLUBXCONFIG,
-            bg=BGCOL,
-            fg=FGCOL,
-            justify=LEFT,
-            font=self.__app.font_md,
-        )
+        self._frm_container = Frame(self, borderwidth=2, relief="groove")
         self._frm_status = Frame(self._frm_container, borderwidth=2, relief="groove")
         self._lbl_status = Label(
             self._frm_status, textvariable=self._status, anchor="w"
@@ -159,9 +143,8 @@ class UBXConfigDialog:
             ipady=5,
             sticky=(N, S, W, E),
         )
-        self._lbl_title.grid(column=col, row=row, columnspan=12, ipadx=3, sticky=(W, E))
         # left column of grid
-        rowsp = 1
+        rowsp = 0
         for frm in (
             self._frm_device_info,
             self._frm_config_port,
@@ -219,6 +202,20 @@ class UBXConfigDialog:
         self._frm_config_port.reset()
         self._frm_device_info.reset()
 
+    def _centre(self):
+        """
+        Roughly center dialog in master window
+        NB: behaviour is slightly different across Windows, MacOS and Linux
+        """
+
+        dw = self.winfo_width()
+        dh = self.winfo_height()
+        mx = self.__master.winfo_x()
+        my = self.__master.winfo_y()
+        mw = self.__master.winfo_width()
+        mh = self.__master.winfo_height()
+        self.geometry(f"+{int(mx + (mw/2 - dw/2))}+{int(my + (mh/2 - dh/2))}")
+
     def set_pending(self, key: int, val: list):
         """
         Set pending confirmation flag for configuration widget to
@@ -280,7 +277,7 @@ class UBXConfigDialog:
 
         self.__master.update_idletasks()
         self.__app.stop_config_thread()
-        self._dialog.destroy()
+        self.destroy()
 
     def get_size(self):
         """
@@ -291,7 +288,7 @@ class UBXConfigDialog:
         """
 
         self.__master.update_idletasks()  # Make sure we know about any resizing
-        return (self._dialog.winfo_width(), self._dialog.winfo_height())
+        return (self.winfo_width(), self.winfo_height())
 
     @property
     def container(self):
