@@ -3,7 +3,9 @@ UBX Configuration widget for preset and user-defined commands
 
 Created on 22 Dec 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: BSD 3-Clause
 """
 # pylint: disable=invalid-name, too-many-instance-attributes, too-many-ancestors
 
@@ -38,6 +40,7 @@ from .globals import (
     ICON_CONFIRMED,
     UBX_PRESET,
 )
+from .helpers import ConfirmBox
 from .strings import (
     LBLPRESET,
     DLGRESET,
@@ -97,8 +100,10 @@ class UBX_PRESET_Frame(Frame):
         """
         Constructor.
 
-        :param object app: reference to main tkinter application
-        :param frame container: container frame
+        :param Frame app: reference to main tkinter application
+        :param Frame container: reference to container frame (config-dialog)
+        :param args: optional args to pass to Frame parent class
+        :param kwargs: optional kwargs to pass to Frame parent class
         """
 
         self.__app = app  # Reference to main application class
@@ -115,7 +120,7 @@ class UBX_PRESET_Frame(Frame):
         self._body()
         self._do_layout()
         self._attach_events()
-        self._reset()
+        self.reset()
 
     def _body(self):
         """
@@ -179,7 +184,7 @@ class UBX_PRESET_Frame(Frame):
 
         self._lbx_preset.bind("<<ListboxSelect>>", self._on_select_preset)
 
-    def _reset(self):
+    def reset(self):
         """
         Reset panel.
         """
@@ -450,11 +455,12 @@ class UBX_PRESET_Frame(Frame):
         Restore to factory defaults stored in battery-backed RAM
         but display confirmation message box first.
 
-        :return boolean signifying whether OK was pressed
-        :rtype bool
+        :return: boolean signifying whether OK was pressed
+        :rtype: bool
         """
 
-        if messagebox.askokcancel(DLGRESET, DLGRESETCONFIRM):
+        if ConfirmBox(self, DLGRESET, DLGRESETCONFIRM).show():
+            # if messagebox.askokcancel(DLGRESET, DLGRESETCONFIRM):
             clearMask = b"\x1f\x1f\x00\x00"
             loadMask = b"\x1f\x1f\x00\x00"
             deviceMask = b"\x07"  # target RAM, Flash and EEPROM
@@ -476,11 +482,12 @@ class UBX_PRESET_Frame(Frame):
         Save current configuration to persistent storage
         but display confirmation message box first.
 
-        :return boolean signifying whether OK was pressed
-        :rtype bool
+        :return: boolean signifying whether OK was pressed
+        :rtype: bool
         """
 
-        if messagebox.askokcancel(DLGSAVE, DLGSAVECONFIRM):
+        if ConfirmBox(self, DLGSAVE, DLGSAVECONFIRM).show():
+            # if messagebox.askokcancel(DLGSAVE, DLGSAVECONFIRM):
             saveMask = b"\x1f\x1f\x00\x00"
             deviceMask = b"\x07"  # target RAM, Flash and EEPROM
             msg = UBXMessage(
@@ -522,6 +529,9 @@ class UBX_PRESET_Frame(Frame):
     def update_status(self, cfgtype, **kwargs):
         """
         Update pending confirmation status.
+
+        :param str cfgtype: identity of UBX message containing config info
+        :param kwargs: status keywords and values from UBX config message
         """
 
         if cfgtype in ("ACK-ACK", "MON-VER"):
